Index: src/x87/regexp-macro-assembler-x87.cc |
diff --git a/src/x87/regexp-macro-assembler-x87.cc b/src/x87/regexp-macro-assembler-x87.cc |
index 54dd52f23aa22b128da6b9a536819f32c2837a10..9bd08caa2ac4567be4e9aa5dc02f0a3862d677f0 100644 |
--- a/src/x87/regexp-macro-assembler-x87.cc |
+++ b/src/x87/regexp-macro-assembler-x87.cc |
@@ -219,7 +219,7 @@ void RegExpMacroAssemblerX87::CheckNotBackReferenceIgnoreCase( |
__ add(eax, ebx); |
BranchOrBacktrack(greater, on_no_match); |
- if (mode_ == ASCII) { |
+ if (mode_ == LATIN1) { |
Label success; |
Label fail; |
Label loop_increment; |
@@ -365,7 +365,7 @@ void RegExpMacroAssemblerX87::CheckNotBackReference( |
Label loop; |
__ bind(&loop); |
- if (mode_ == ASCII) { |
+ if (mode_ == LATIN1) { |
__ movzx_b(eax, Operand(edx, 0)); |
__ cmpb_al(Operand(ebx, 0)); |
} else { |
@@ -475,7 +475,7 @@ void RegExpMacroAssemblerX87::CheckBitInTable( |
Label* on_bit_set) { |
__ mov(eax, Immediate(table)); |
Register index = current_character(); |
- if (mode_ != ASCII || kTableMask != String::kMaxOneByteCharCode) { |
+ if (mode_ != LATIN1 || kTableMask != String::kMaxOneByteCharCode) { |
__ mov(ebx, kTableSize - 1); |
__ and_(ebx, current_character()); |
index = ebx; |
@@ -492,7 +492,7 @@ bool RegExpMacroAssemblerX87::CheckSpecialCharacterClass(uc16 type, |
switch (type) { |
case 's': |
// Match space-characters |
- if (mode_ == ASCII) { |
+ if (mode_ == LATIN1) { |
// One byte space characters are '\t'..'\r', ' ' and \u00a0. |
Label success; |
__ cmp(current_character(), ' '); |
@@ -542,8 +542,8 @@ bool RegExpMacroAssemblerX87::CheckSpecialCharacterClass(uc16 type, |
return true; |
} |
case 'w': { |
- if (mode_ != ASCII) { |
- // Table is 128 entries, so all ASCII characters can be tested. |
+ if (mode_ != LATIN1) { |
+ // Table is 256 entries, so all Latin1 characters can be tested. |
__ cmp(current_character(), Immediate('z')); |
BranchOrBacktrack(above, on_no_match); |
} |
@@ -556,8 +556,8 @@ bool RegExpMacroAssemblerX87::CheckSpecialCharacterClass(uc16 type, |
} |
case 'W': { |
Label done; |
- if (mode_ != ASCII) { |
- // Table is 128 entries, so all ASCII characters can be tested. |
+ if (mode_ != LATIN1) { |
+ // Table is 256 entries, so all Latin1 characters can be tested. |
__ cmp(current_character(), Immediate('z')); |
__ j(above, &done); |
} |
@@ -566,7 +566,7 @@ bool RegExpMacroAssemblerX87::CheckSpecialCharacterClass(uc16 type, |
__ test_b(current_character(), |
Operand::StaticArray(current_character(), times_1, word_map)); |
BranchOrBacktrack(not_zero, on_no_match); |
- if (mode_ != ASCII) { |
+ if (mode_ != LATIN1) { |
__ bind(&done); |
} |
return true; |
@@ -583,7 +583,7 @@ bool RegExpMacroAssemblerX87::CheckSpecialCharacterClass(uc16 type, |
// See if current character is '\n'^1 or '\r'^1, i.e., 0x0b or 0x0c |
__ sub(eax, Immediate(0x0b)); |
__ cmp(eax, 0x0c - 0x0b); |
- if (mode_ == ASCII) { |
+ if (mode_ == LATIN1) { |
BranchOrBacktrack(above, on_no_match); |
} else { |
Label done; |
@@ -1098,7 +1098,7 @@ int RegExpMacroAssemblerX87::CheckStackGuardState(Address* return_address, |
Handle<String> subject(frame_entry<String*>(re_frame, kInputString)); |
// Current string. |
- bool is_ascii = subject->IsOneByteRepresentationUnderneath(); |
+ bool is_one_byte = subject->IsOneByteRepresentationUnderneath(); |
DCHECK(re_code->instruction_start() <= *return_address); |
DCHECK(*return_address <= |
@@ -1129,8 +1129,8 @@ int RegExpMacroAssemblerX87::CheckStackGuardState(Address* return_address, |
} |
// String might have changed. |
- if (subject_tmp->IsOneByteRepresentation() != is_ascii) { |
- // If we changed between an ASCII and an UC16 string, the specialized |
+ if (subject_tmp->IsOneByteRepresentation() != is_one_byte) { |
+ // If we changed between an LATIN1 and an UC16 string, the specialized |
// code cannot be used, and we need to restart regexp matching from |
// scratch (including, potentially, compiling a new version of the code). |
return RETRY; |
@@ -1277,7 +1277,7 @@ void RegExpMacroAssemblerX87::CheckStackLimit() { |
void RegExpMacroAssemblerX87::LoadCurrentCharacterUnchecked(int cp_offset, |
int characters) { |
- if (mode_ == ASCII) { |
+ if (mode_ == LATIN1) { |
if (characters == 4) { |
__ mov(current_character(), Operand(esi, edi, times_1, cp_offset)); |
} else if (characters == 2) { |